@@ -121,7 +121,7 @@ MANUAL_SR_IN="""---Stopping/Range Input Data (Number-format: Period = Decimal Po
 ---Output Stopping Units (1-8)
  7
 ---Ion Energy : E-Min(keV), E-Max(keV)
- 10    10000
+ 100    20000
 """;
 
 @contextmanager
@@ -149,10 +149,14 @@ def load_SR_file( SRFile ):
     units_ok=False
     kevum=0.0
     mevmg=0.0  # MeV/mg/cm2
+    print("D... opening SRFile", SRFile)
     with open( SRFile ) as f:
         li=f.readlines()
 
+
     li=[x.rstrip() for x in li] # remove \n
+    #print("\n".join(li))
+
     begin,end=0,len(li)
     for i in range(len(li)):
         if (li[i].find("Energy")>=0) and  (li[i].find("Nuclear")>=0):
@@ -207,7 +211,7 @@ def run_sr_exe( SRINFILE=MANUAL_SR_IN,  silent=True):
     temppath = tempfile.mkdtemp(prefix='sr_')+'/'
     if not silent: print('DDD... SR.IN ... copying from',RPATH,'to',temppath)
     copy_tree( RPATH , temppath )
-    #print("DDD...  copied")
+    print("D...  copied", temppath)
     with cd(temppath+'SR Module/'):
         if not silent:print("DDD... cd "+temppath+'SR\\ Module/')
         #srin=MANUAL_SR_IN.replace("OOOUTPUTFILE", OUTPUTFILE)+"\n"
@@ -232,7 +236,10 @@ def run_sr_exe( SRINFILE=MANUAL_SR_IN,  silent=True):
             print("\n############### VDISPLAY #########################stop")
 
         if not silent:print("DDD...  reading losses of SR.IN from ouput")
+        #print("D... loading SR OUTPUTFILE",OUTPUTFILE)
         eneloss,kevum,mevmg=load_SR_file( OUTPUTFILE )
+        #print("D... loaded")
+
         #print("losses and keV/um coef read")
     #print( "output==",eneloss )
     return eneloss,kevum,mevmg  # DICT WITH LOSSES
@@ -316,6 +323,9 @@ def get_sr_loss( SRIN , Emax=5.8, dmax=10 , unit="um" ):
     if unit=="mg":
         for k in eneloss.keys():
             eneloss2[k]=eneloss[k]* mevmg
+    if unit=="ug":
+        for k in eneloss.keys():
+            eneloss2[k]=eneloss[k]* mevmg/1000
             #print(  "       --> ",eneloss[k] )
     #print("i...   SR.IN coef:  keV/um",kevum)  # keV/um for loss simulation
     #print("i...   SR.IN coef:  MeV/mg/cm2",mevmg)  #  for loss simulation
@@ -339,7 +349,7 @@ def get_sr_loss( SRIN , Emax=5.8, dmax=10 , unit="um" ):
             e=e- tcks( min(tcks.x) )*dx  # ticks[MeV/um] => Emax[MeV]
         x=x+dx
         #print(x, e)
-    print("last two steps : {} {}   {} {}".format(x,e,xs,es) )
+    print("i... interpol: last two (x,e): {:.1f} {:.3f}   {:.1f} {:.3f}".format(x,e,xs,es) )
     dde=(dmax-xs)*(es-e)/(xs-x)
     if  es+dde < 0:
         print("_"*30,"\n\nE_SRIN = {:.5g}\n".format( 0 ) ,"_"*30 )
@@ -1026,7 +1036,7 @@ def targ(  name, thick,   ion,  outerdens  , SRLINE ):
     SRLINE.append("---Output Stopping Units (1-8)")
     SRLINE.append(" 7")
     SRLINE.append("---Ion Energy : E-Min(keV), E-Max(keV)")
-    SRLINE.append(" 10    50000")
+    SRLINE.append(" 10    99000")
 
     #======================= I AM DONE WITH SR.IN for isotope or element================
 
@@ -1146,7 +1156,7 @@ def run_srim(RPATH, TRIMIN , strip=True, silent=False , nmax=1 ):
         with open('TRIMAUTO','w') as f:
             f.write( TRIMAUTO )
             f.close()
-        if not silent: print('i...   TRIM.IN  and TRIMAUTO written')
+        # if not silent: print('i...   TRIM.IN  and TRIMAUTO written')
         if isjupyter():
             print('i... JuPyter detected - vdislay initiated')
             silent=True #### PROBLEM with X in Jupyter?
@@ -1625,6 +1635,7 @@ def prepare_trimin( material,  thick,  rho  , incomming0 , Eini, angle, number,
     TRIMIN,SRIN=PrepSrimFile( ion=incomming0, energy=Eini, angle=0., number=number,
                             mater=material, thick=thick, dens=rho  )
     print('DDD... after PrepSrimFile',Eini, thick)
+    print("D... SRIN==",SRIN)
     get_sr_loss( SRIN , Eini, thick , unit="mg")
 
     return TRIMIN
